@@ -7,7 +7,7 @@ use utf8;
 
 BEGIN {
 	$App::perlrdf::Command::Prefix::AUTHORITY = 'cpan:TOBYINK';
-	$App::perlrdf::Command::Prefix::VERSION   = '0.003';
+	$App::perlrdf::Command::Prefix::VERSION   = '0.005';
 }
 
 use App::perlrdf -command;
@@ -32,12 +32,12 @@ sub execute
 	my ($self, $opt, $arg) = @_;
 	
 	my $method;
-	given ($opt->{format} // '')
+	for ($opt->{format} // '')
 	{
-		when (/turtle|ttl/i)    { $method = 'TTL' }
-		when (/sparql/i)        { $method = 'SPARQL' }
-		when (/xmlns|xml/i)     { $method = 'XMLNS' }
-		default                 { $method = 'TXT' }
+		if    (/turtle|ttl/i) { $method = 'TTL' }
+		elsif (/sparql/i)     { $method = 'SPARQL' }
+		elsif (/xmlns|xml/i)  { $method = 'XMLNS' }
+		else                  { $method = 'TXT' }
 	}
 	
 	say for RDF::NS->new('any')->$method(join q<,>, @$arg);
